@@ -14,8 +14,4 @@
 #
 # You should have received a copy of the GNU Lesser General Public
 # License along with this library.
-
-from __future__ import print_function
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
+from __future__ import annotations
